@@ -15,11 +15,11 @@ class bughelper(object):
 
 class bugnumbers(object):
     def data(self,content):
-        return "%s (%s, %s) - %s" %(content["bug"].bugnumber, content["bug"].status,
-                content["bug"].importance,content["bug"].summary)
+        x = content["bug"]
+        return "%s (%s, %s) - %s" %(x.bugnumber, x.status, x.importance, x.summary)
         
     def comments(self,content):
-        return "https://bugs.launchpad.net/ubuntu/+bug/%s Comments %i" %(content["bug"],
+        return "https://bugs.launchpad.net/ubuntu/+bug/%s Comments %i" %(int(content["bug"]),
                 content["count"])
     
     def statistic(self,content):
