@@ -15,4 +15,11 @@ class bughelper(object):
                         text += """   * %s
     """ % a
         return """ * [http://launchpad.net/bugs/%s bug #%s] %s:
-    %s""" % (bug.bugnumber, bug.bugnumber, bug.info, text)
\ No newline at end of file
+    %s""" % (bug.bugnumber, bug.bugnumber, bug.info, text)
+    
+   
+class bugnumbers(object):
+    def data(self,content):
+        bug = content["bug"]
+        return """||<rowstyle="background-color: ;"> [%s %s ] || %s/%s || %s ||""" %(bug.url, int(bug), bug.status, bug.importance, bug.summary)
+
